@@ -50,9 +50,13 @@ def get_data(save_dataset_fd,documents):
     test_data = torch_geometric.data.Batch.from_data_list(test_list_of_graphs)
     test_data.edge_attr = None
 
-    torch.save(train_data, os.path.join(save_dataset_fd, 'train_data.dataset'))
-    torch.save(test_data, os.path.join(save_dataset_fd, 'test_data.dataset'))
+    train_data_dataset_path = os.path.join(save_dataset_fd, 'train_data.dataset')
+    test_data_dataset_path = os.path.join(save_dataset_fd, 'test_data.dataset')
 
+    torch.save(train_data, train_data_dataset_path)
+    torch.save(test_data, test_data_dataset_path)
+
+    return save_dataset_fd
 
 def makeIndividualData(file):
     connect = Grapher(file)
