@@ -60,7 +60,7 @@ class Grapher:
         temp = df.copy()
         temp[temp.columns] = temp.apply(lambda x: x.str.strip())
         temp.fillna('', inplace=True)
-        temp.columns = ['xmin', 'ymin', 'xmax', 'ymax', 'Object']
+        temp.columns = ['xmin', 'ymin', 'xmax', 'ymax', 'Object','Tag']
         temp[['xmin', 'ymin', 'xmax', 'ymax']] = temp[['xmin', 'ymin', 'xmax', 'ymax']].apply(pd.to_numeric)
         df = temp
 
