@@ -3,8 +3,8 @@ import shutil
 import numpy as np
 import torch
 
-from Graph import Grapher
-from Data_for_gcn import load_predictionData
+from graphmanagerlib.Graph import Grapher
+from graphmanagerlib.Data_for_gcn import load_predictionData
 from torch_geometric.utils.convert import from_networkx
 
 
